========
 z3c.pt
========

.. image:: https://img.shields.io/pypi/v/z3c.pt.svg
        :target: https://pypi.python.org/pypi/z3c.pt/
        :alt: Latest release

.. image:: https://img.shields.io/pypi/pyversions/z3c.pt.svg
        :target: https://pypi.org/project/z3c.pt/
        :alt: Supported Python versions

.. image:: https://github.com/zopefoundation/z3c.pt/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/z3c.pt/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/z3c.pt/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/z3c.pt?branch=master

.. image:: https://readthedocs.org/projects/z3cpt/badge/?version=latest
        :target: https://z3cpt.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

This is a fast implementation of the ZPT template engine for Zope 3
which uses Chameleon to compile templates to byte-code.

The package provides application support equivalent to
``zope.pagetemplate``.
